#ifndef MICROPY_INCLUDED_LCDI2C_H
#define MICROPY_INCLUDED_LCDI2C_H

#include "py/runtime.h"
#include "py/obj.h"
#include "py/objstr.h"
#include "py/objarray.h"
#include "py/mphal.h"

// Forward declarations
typedef struct _lcdi2c_i2cbus_obj_t lcdi2c_i2cbus_obj_t;

// I2CBus object structure
typedef struct _lcdi2c_i2cbus_obj_t {
    mp_obj_base_t base;
    
    // I2C configuration
    uint8_t host;             // I2C host/peripheral number (0 or 1 for RP2040)
    uint8_t sda_pin;          // SDA pin number
    uint8_t scl_pin;          // SCL pin number
    uint8_t addr;             // Device I2C address
    uint32_t freq;            // I2C frequency in Hz
    bool sda_pullup;          // Enable internal pullup for SDA
    bool scl_pullup;          // Enable internal pullup for SCL
    
    // Control phase configuration
    uint8_t control_phase_bytes;  // Number of control phase bytes
    uint8_t dc_bit_offset;        // Data/Command bit offset in control byte
    bool dc_low_on_data;          // Is DC bit low for data (vs command)
    bool disable_control_phase;   // Disable control phase entirely
    
    // Display configuration
    uint16_t width;
    uint16_t height;
    uint8_t bpp;
    uint16_t buffer_size;
    bool rgb565_byte_swap;
    uint8_t cmd_bits;
    uint8_t param_bits;
    
    // Hardware handles
    void* i2c_inst;           // Pointer to RP2040 I2C instance
    mp_obj_t callback;        // Python callback function
    
    // Framebuffer management
    void* framebuffer;
    uint32_t framebuffer_size;
} lcdi2c_i2cbus_obj_t;

// Exported functions
extern const mp_obj_type_t lcdi2c_i2cbus_type;

#endif // MICROPY_INCLUDED_LCDI2C_H