import lcdi2c
import time

# Initialize the I2C bus for an LCD with address 0x3C
lcd_bus = lcdi2c.I2CBus(sda=4, scl=5, addr=0x3C)

# Initialize display characteristics 
lcd_bus.init(width=128, height=64, bpp=1, buffer_size=1024, 
             rgb565_byte_swap=False, cmd_bits=8, param_bits=8)

# Define common display commands (these may vary depending on your specific LCD)
CMD_DISPLAY_ON = 0xAF
CMD_DISPLAY_OFF = 0xAE
CMD_SET_CONTRAST = 0x81
CMD_SET_NORMAL_DISPLAY = 0xA6
CMD_SET_INVERSE_DISPLAY = 0xA7
CMD_SET_ADDRESS_MODE = 0x20
CMD_CLEAR_DISPLAY = 0x01

# Allocate framebuffer (assuming DMA capability is 0 for simplicity)
framebuffer = lcd_bus.allocate_framebuffer(lcd_bus.buffer_size, 0)
if framebuffer:
    print("Framebuffer allocated successfully")

# Basic display initialization sequence
print("Initializing display...")
lcd_bus.tx_param(CMD_DISPLAY_OFF)  # Turn display off during init
time.sleep(0.1)

# Set display contrast
lcd_bus.tx_param(CMD_SET_CONTRAST, bytearray([0x7F]))  # Medium contrast
time.sleep(0.05)

# Set normal display mode (not inverted)
lcd_bus.tx_param(CMD_SET_NORMAL_DISPLAY)
time.sleep(0.05)

# Turn on the display
lcd_bus.tx_param(CMD_DISPLAY_ON)
print("Display turned on")
time.sleep(1)

# Test display by filling with patterns
def fill_buffer(pattern):
    """Fill the framebuffer with a pattern"""
    for i in range(len(framebuffer)):
        framebuffer[i] = pattern

# Draw a pattern to the display
print("Drawing pattern...")
fill_buffer(0xAA)  # Alternating bits pattern
lcd_bus.tx_color(0x2C, framebuffer, 0, 0, 127, 63, 0, True)
time.sleep(2)

# Invert the display
print("Inverting display...")
lcd_bus.tx_param(CMD_SET_INVERSE_DISPLAY)
time.sleep(2)

# Restore normal display
lcd_bus.tx_param(CMD_SET_NORMAL_DISPLAY)
time.sleep(1)

# Fill with different pattern
print("Drawing different pattern...")
fill_buffer(0x55)  # Different alternating pattern
lcd_bus.tx_color(0x2C, framebuffer, 0, 0, 127, 63, 0, True)
time.sleep(2)

# Test display off
print("Turning display off...")
lcd_bus.tx_param(CMD_DISPLAY_OFF)
time.sleep(1)

# Turn display back on
print("Turning display on...")
lcd_bus.tx_param(CMD_DISPLAY_ON)
time.sleep(1)

# Clear the display (all zeros)
print("Clearing display...")
fill_buffer(0x00)
lcd_bus.tx_color(0x2C, framebuffer, 0, 0, 127, 63, 0, True)
time.sleep(1)

# Free the framebuffer when done
lcd_bus.free_framebuffer(framebuffer)
print("Framebuffer freed")

# Deinitialize I2C bus
lcd_bus.deinit()
print("Test completed")