#ifndef MICROPY_INCLUDED_LCDRGB_RP2_H
#define MICROPY_INCLUDED_LCDRGB_RP2_H

#include "py/runtime.h"
#include "py/obj.h"
#include "py/objstr.h"
#include "py/objarray.h"
#include "py/mphal.h"

#include "hardware/pio.h"
#include "hardware/dma.h"

// Forward declarations
typedef struct _lcdrgb_rgbbus_obj_t lcdrgb_rgbbus_obj_t;

// RGBBus object structure for RP2040
typedef struct _lcdrgb_rgbbus_obj_t {
    mp_obj_base_t base;
    
    // GPIO pin assignments
    uint8_t hsync_pin;
    uint8_t vsync_pin;
    uint8_t de_pin;
    uint8_t pclk_pin;
    uint8_t data_pins[16];  // Up to 16 data pins
    uint32_t freq;
    
    // Timing parameters
    uint16_t hsync_front_porch;
    uint16_t hsync_back_porch;
    uint16_t hsync_pulse_width;
    bool hsync_idle_low;
    uint16_t vsync_front_porch;
    uint16_t vsync_back_porch;
    uint16_t vsync_pulse_width;
    bool vsync_idle_low;
    bool de_idle_high;
    bool pclk_idle_high;
    bool pclk_active_low;
    bool disp_active_low;
    bool refresh_on_demand;
    bool rgb565_dither;
    
    // Display configuration
    uint16_t width;
    uint16_t height;
    uint8_t bpp;
    uint16_t buffer_size;
    bool rgb565_byte_swap;
    uint8_t cmd_bits;
    uint8_t param_bits;
    
    // PIO and DMA resources
    PIO pio;
    uint sm_timing;        // State machine for HSYNC, VSYNC, DE
    uint sm_data;          // State machine for data signals
    uint data_prog_offset; // PIO program offset for data program
    uint timing_prog_offset; // PIO program offset for timing signals
    int dma_channel;      // DMA channel for frame data
    int dma_channel_cfg;  // Configuration DMA channel
    
    // Callback and framebuffer
    mp_obj_t callback;
    void* framebuffer;
    uint32_t framebuffer_size;
    uint8_t lane_count;
    
} lcdrgb_rgbbus_obj_t;

// Exported functions
extern const mp_obj_type_t lcdrgb_rgbbus_type;

// Implementation functions
void lcdrgb_init_pio(lcdrgb_rgbbus_obj_t *self);
void lcdrgb_deinit_pio(lcdrgb_rgbbus_obj_t *self);
void lcdrgb_update_display(lcdrgb_rgbbus_obj_t *self);

#endif // MICROPY_INCLUDED_LCDRGB_RP2_H