import lcdi2c

# Create I2C bus for a display
i2c = lcdi2c.I2CBus(
    sda=21,           # SDA pin
    scl=22,           # SCL pin
    addr=0x3C,        # Display I2C address
    freq=400000,      # 400 KHz frequency
    dc_bit_offset=6,  # Control/data bit position in control byte
)

# Initialize display parameters
i2c.init(128, 64, 1, 1024, False, 8, 8)

# Send command 0xAF (display on)
i2c.tx_param(0xAF)

# Send command 0x21 with parameters [0, 127]
i2c.tx_param(0x21, bytearray([0, 127]))

# Send pixel data
buf = bytearray(1024)  # Create a buffer with 1024 bytes
for i in range(1024):
    buf[i] = 0xAA  # Checkerboard pattern
i2c.tx_color(0x22, buf, 0, 0, 127, 63, 0, True)

# Receive status
status = bytearray(1)
i2c.rx_param(0x00, status)
print(f"Display status: {status[0]:08b}")

# Cleanup when done
i2c.deinit()