#ifndef MICROPY_INCLUDED_LCDI8080_H
#define MICROPY_INCLUDED_LCDI8080_H

#include "py/runtime.h"
#include "py/obj.h"
#include "py/objstr.h"
#include "py/objarray.h"
#include "py/mphal.h"

// Forward declarations
typedef struct _lcdi8080_i80bus_obj_t lcdi8080_i80bus_obj_t;

// I80Bus object structure
typedef struct _lcdi8080_i80bus_obj_t {
    mp_obj_base_t base;
    
    // Pin configuration
    uint8_t dc_pin;           // Data/Command pin
    uint8_t wr_pin;           // Write strobe pin
    uint8_t cs_pin;           // Chip select pin
    
    // Data pins (up to 16-bit bus width)
    uint8_t data_pins[16];    // Data pins 0-15
    uint8_t data_width;       // Number of data pins (8 or 16)
    
    // Bus configuration
    uint32_t freq;            // Bus frequency
    bool dc_idle_high;        // DC pin idle state
    bool dc_cmd_high;         // DC pin state for commands
    bool dc_dummy_high;       // DC pin state for dummy cycles
    bool dc_data_high;        // DC pin state for data
    bool cs_active_high;      // Chip select active state
    bool reverse_color_bits;  // Reverse color bit order
    bool swap_color_bytes;    // Swap color bytes
    bool pclk_active_low;     // Pixel clock active state
    bool pclk_idle_low;       // Pixel clock idle state
    
    // Display configuration
    uint16_t width;           // Display width
    uint16_t height;          // Display height
    uint8_t bpp;              // Bits per pixel
    uint16_t buffer_size;     // Buffer size
    bool rgb565_byte_swap;    // RGB565 byte swap
    uint8_t cmd_bits;         // Command bit width
    uint8_t param_bits;       // Parameter bit width
    
    // Hardware handles
    FMC_NORSRAM_TypeDef* fmc_bank;  // FMC bank
    uint32_t fmc_timing;            // FMC timing
    mp_obj_t callback;              // User callback function
    
    // Framebuffer management
    void* framebuffer;        // Display framebuffer
    uint32_t framebuffer_size;// Framebuffer size
} lcdi8080_i80bus_obj_t;

// Exported functions
extern const mp_obj_type_t lcdi8080_i80bus_type;

#endif // MICROPY_INCLUDED_LCDI8080_H