import lcdi8080

# Create I80Bus for a display (typical configuration for a TFT LCD)
display = lcdi8080.I80Bus(
    # Control pins
    dc=14,           # Data/Command pin
    wr=15,           # Write strobe pin
    
    # 8-bit data bus pins (D0-D7)
    data0=16,
    data1=17,
    data2=18,
    data3=19,
    data4=20,
    data5=21,
    data6=22,
    data7=23,
    
    # Optional 16-bit data bus pins (D8-D15) - not used in this example
    # data8=24,
    # data9=25,
    # data10=26,
    # data11=27,
    # data12=28,
    # data13=29,
    # data14=30,
    # data15=31,
    
    cs=13,           # Chip select pin
    freq=20000000,   # 20 MHz bus frequency
    dc_data_high=True,  # DC high for data
    cs_active_high=False  # CS active low
)

# Initialize display parameters (for a typical 320x240 LCD)
display.init(320, 240, 16, 320*240*2, False, 8, 8)

# Allocate framebuffer
framebuffer = display.allocate_framebuffer(320*240*2, 0)

# Send initialization commands (example for HX8357D)
# Software reset
display.tx_param(0x01)
# Wait for reset to complete (in real code, use a delay here)
import time
time.sleep_ms(10)

# Set Power Control
display.tx_param(0xB1, bytearray([0x00, 0x15, 0x0D, 0x0D, 0x83, 0x48]))
# Set Display Mode
display.tx_param(0xB4, bytearray([0x00, 0x78]))
# Set VCOM Voltage
display.tx_param(0xC0, bytearray([0x24, 0x24, 0x01, 0x3C, 0xC8, 0x08]))
# Set Panel
display.tx_param(0xB6, bytearray([0x80, 0x00, 0x27, 0x28]))
# Set Gamma Curve
display.tx_param(0xE0, bytearray([0x00, 0x08, 0x0D, 0x2D, 0x34, 0x3F, 0x19, 0x38,
                                 0x09, 0x0E, 0x0E, 0x12, 0x14, 0x12, 0x14, 0x10,
                                 0x17, 0x0D, 0x14, 0x16, 0x10, 0x11, 0x0C, 0x0E,
                                 0x0B, 0x0B, 0x08, 0x02, 0x01, 0x02, 0x01, 0x00]))
# Pixel Format Set
display.tx_param(0x3A, bytearray([0x55]))  # 16-bit color mode
# Turn on display
display.tx_param(0x29)

# Create a test pattern (blue to cyan gradient)
for y in range(240):
    for x in range(320):
        # RGB565 format
        blue = 31
        green = (y * 63) // 240
        index = (y * 320 + x) * 2
        # Convert to RGB565 format
        color = (green << 5) | blue
        framebuffer[index + 0] = color & 0xFF
        framebuffer[index + 1] = (color >> 8) & 0xFF

# Set column address range
display.tx_param(0x2A, bytearray([0x00, 0x00, 0x01, 0x3F]))  # 0-319

# Set page address range
display.tx_param(0x2B, bytearray([0x00, 0x00, 0x00, 0xEF]))  # 0-239

# Send pixel data
display.tx_color(0x2C, framebuffer, 0, 0, 319, 239, 0, True)

# Cleanup when done
display.free_framebuffer(framebuffer)
display.deinit()