#ifndef MICROPY_INCLUDED_LCDRGB_H
#define MICROPY_INCLUDED_LCDRGB_H

#include "py/runtime.h"
#include "py/obj.h"
#include "py/objstr.h"
#include "py/objarray.h"
#include "py/mphal.h"

// Forward declarations
typedef struct _lcdrgb_rgbbus_obj_t lcdrgb_rgbbus_obj_t;

// RGBBus object structure
typedef struct _lcdrgb_rgbbus_obj_t {
    mp_obj_base_t base;
    
    // LTDC and GPIO configuration
    uint8_t hsync_pin;
    uint8_t vsync_pin;
    uint8_t de_pin;
    uint8_t pclk_pin;
    uint8_t data_pins[16];  // Up to 16 data pins
    uint32_t freq;
    
    // Timing parameters
    uint16_t hsync_front_porch;
    uint16_t hsync_back_porch;
    uint16_t hsync_pulse_width;
    bool hsync_idle_low;
    uint16_t vsync_front_porch;
    uint16_t vsync_back_porch;
    uint16_t vsync_pulse_width;
    bool vsync_idle_low;
    bool de_idle_high;
    bool pclk_idle_high;
    bool pclk_active_low;
    bool disp_active_low;
    bool refresh_on_demand;
    bool rgb565_dither;
    
    // Display configuration
    uint16_t width;
    uint16_t height;
    uint8_t bpp;
    uint16_t buffer_size;
    bool rgb565_byte_swap;
    uint8_t cmd_bits;
    uint8_t param_bits;
    
    // Hardware handles
    void* ltdc_handle;
    void* callback;
    
    // Framebuffer management
    void* framebuffer;
    uint32_t framebuffer_size;
    uint8_t lane_count;
    
} lcdrgb_rgbbus_obj_t;

// Exported functions
extern const mp_obj_type_t lcdrgb_rgbbus_type;

#endif // MICROPY_INCLUDED_LCDRGB_H