import lcdrgb

# Create RGBBus for a display (typical configuration for RGB parallel TFT)
display = lcdrgb.RGBBus(
    # Control signals
    hsync=2,         # HSYNC pin
    vsync=3,         # VSYNC pin
    de=4,            # Data Enable pin
    pclk=5,          # Pixel Clock pin
    
    # Data pins (using 8-bit RGB interface)
    data0=6,         # R0
    data1=7,         # R1
    data2=8,         # R2
    data3=9,         # G0
    data4=10,        # G1
    data5=11,        # G2
    data6=12,        # B0
    data7=13,        # B1
    
    # Timing parameters
    freq=10000000,   # 10 MHz pixel clock
    hsync_front_porch=8,
    hsync_back_porch=8,
    hsync_pulse_width=1,
    hsync_idle_low=True,
    vsync_front_porch=4,
    vsync_back_porch=4,
    vsync_pulse_width=1,
    vsync_idle_low=True,
    refresh_on_demand=False,  # Continuous refresh
)

# Initialize display parameters (for a typical 480x272 WQVGA display)
display.init(480, 272, 16, 480*272*2, False, 8, 8)

# Allocate framebuffer
framebuffer = display.allocate_framebuffer(480*272*2, 0)

# Create a test pattern (color gradient)
for y in range(272):
    for x in range(480):
        # RGB565 format
        red = (x * 31) // 480
        green = (y * 63) // 272
        blue = 31 - ((x * 31) // 480)
        
        index = (y * 480 + x) * 2
        # Convert to RGB565 format
        color = (red << 11) | (green << 5) | blue
        framebuffer[index + 0] = color & 0xFF
        framebuffer[index + 1] = (color >> 8) & 0xFF

# In RGB mode, display is automatically updated from framebuffer
# No need to explicitly send the data

# Draw a white rectangle in the center
rect_width = 100
rect_height = 60
x_start = (480 - rect_width) // 2
y_start = (272 - rect_height) // 2

for y in range(y_start, y_start + rect_height):
    for x in range(x_start, x_start + rect_width):
        index = (y * 480 + x) * 2
        # White color in RGB565: 0xFFFF
        framebuffer[index + 0] = 0xFF
        framebuffer[index + 1] = 0xFF

# For RGB displays, we typically don't need to send commands,
# but we'll call tx_param for demonstration purposes
# This might actually control an additional command interface
# to the display controller, if available
display.tx_param(0x2C)  # Memory write command (not used in pure RGB interfaces)

# Cleanup when done
display.free_framebuffer(framebuffer)
display.deinit()