#ifndef MICROPY_INCLUDED_LCDSPI_H
#define MICROPY_INCLUDED_LCDSPI_H

#include "py/runtime.h"
#include "py/obj.h"
#include "py/objstr.h"
#include "py/objarray.h"
#include "py/mphal.h"

// Forward declarations
typedef struct _lcdspi_spibus_obj_t lcdspi_spibus_obj_t;

// SPIBus object structure
typedef struct _lcdspi_spibus_obj_t {
    mp_obj_base_t base;
    
    // SPI and GPIO configuration
    uint8_t spi_bus;
    uint8_t dc_pin;
    uint8_t cs_pin;
    uint32_t freq;
    bool dc_low_on_data;
    bool lsb_first;
    bool cs_high_active;
    uint8_t spi_mode;
    bool dual;
    bool quad;
    bool octal;
    
    // Display configuration
    uint16_t width;
    uint16_t height;
    uint8_t bpp;
    uint16_t buffer_size;
    bool rgb565_byte_swap;
    uint8_t cmd_bits;
    uint8_t param_bits;
    
    // Hardware handles
    void* spi_handle;
    void* callback;
    
    // Framebuffer management
    void* framebuffer;
    uint32_t framebuffer_size;
} lcdspi_spibus_obj_t;

// Exported functions
extern const mp_obj_type_t lcdspi_spibus_type;

#endif // MICROPY_INCLUDED_LCDSPI_H