import lcdspi
import machine

# Create a hardware SPI bus first (or use existing one)
# In this example, we'll use an integer to represent SPI bus ID
spi_bus_id = 1  # Use SPI1

# Create SPI bus for a display (typical configuration for ILI9341)
display = lcdspi.SPIBus(
    spi_bus=spi_bus_id,  # SPI bus ID
    dc=16,               # Data/Command pin
    freq=40000000,       # 40 MHz frequency
    cs=17,               # Chip select pin
    dc_low_on_data=False,# DC high for data
    spi_mode=0           # SPI mode 0 (CPOL=0, CPHA=0)
)

# Initialize display parameters (ILI9341 typical params)
display.init(240, 320, 16, 240*320*2, True, 8, 8)

# Allocate framebuffer for display updates
framebuffer = display.allocate_framebuffer(240*320*2, 0)

# Send initialization commands
# Power control
display.tx_param(0xCB, bytearray([0x39, 0x2C, 0x00, 0x34, 0x02]))
# Power control
display.tx_param(0xCF, bytearray([0x00, 0xC1, 0x30]))
# Driver timing control
display.tx_param(0xE8, bytearray([0x85, 0x00, 0x78]))
# Driver timing control
display.tx_param(0xEA, bytearray([0x00, 0x00]))
# Power control
display.tx_param(0xED, bytearray([0x64, 0x03, 0x12, 0x81]))
# Pump ratio control
display.tx_param(0xF7, bytearray([0x20]))
# Power control
display.tx_param(0xC0, bytearray([0x23]))
# Power control
display.tx_param(0xC1, bytearray([0x10]))
# VCOM control
display.tx_param(0xC5, bytearray([0x3E, 0x28]))
# VCOM control
display.tx_param(0xC7, bytearray([0x86]))
# Memory Access Control (orientation)
display.tx_param(0x36, bytearray([0x48]))
# Pixel Format Set
display.tx_param(0x3A, bytearray([0x55]))  # 16-bit color
# Frame Rate Control
display.tx_param(0xB1, bytearray([0x00, 0x18]))
# Display Function Control
display.tx_param(0xB6, bytearray([0x08, 0x82, 0x27]))
# Exit Sleep Mode
display.tx_param(0x11)
# Turn on display
display.tx_param(0x29)

# Create test pattern (red gradient)
for i in range(240*320):
    # RGB565 format: Red gradient
    red = (i % 32) * 8
    framebuffer[i*2] = red
    framebuffer[i*2+1] = 0

# Set column address range
display.tx_param(0x2A, bytearray([0x00, 0x00, 0x00, 0xEF]))  # 0-239

# Set page address range
display.tx_param(0x2B, bytearray([0x00, 0x00, 0x01, 0x3F]))  # 0-319

# Send pixel data
display.tx_color(0x2C, framebuffer, 0, 0, 239, 319, 0, True)

# Read display status (optional)
status = bytearray(1)
display.rx_param(0x09, status)
print(f"Display status: {status[0]:02x}")

# Cleanup when done
display.free_framebuffer(framebuffer)
display.deinit()